##  Overview
The workspace admin configures default notification settings for all workspace users. You can customize these default settings based on your preferences. You can adjust the frequency of notifications for specific items such as fact sheets, saved searches, surveys, to-dos, and more. For example, you can choose how often you want to be notified when an update is made to a fact sheet for which you're Accountable, or when someone subscribes you to a fact sheet.
Notifications are sent in the language that you selected in your user profile. If no language preference is set, the default workspace language is used. Changes to your preferred language may take some time to reflect in notifications.
Admin users can configure notification settings for a workspace. For details, see [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center?locale=en-US&state=PRODUCTION&version=CLOUD "Configure notification settings for your workspace.").
**Note**
You receive notifications only for actions performed by other users, not for your own actions.
